package FBP::BoxSizer;

use Moose;

our $VERSION = '0.02';

extends 'FBP::Sizer';

1;
